body {
	font-family: "Lucida Sans Unicode", "Lucida Grande", Sans-Serif;
	font-size:12px;
}

table
  {
	border-spacing: 0; 	
	border: 1px;
	width: 95%;
	margin:20px;
  }

thead th {
	background-color: lightblue;
	white-space: nowrap;
	text-align:center;
	padding:10px 20px;
        transition: background .25s ease-in-out;
}

tbody tr {
        transition: background .25s ease-in-out;
}

tbody tr td, tbody tr td a 
  {
	max-width: 300px;
	text-align: left;
	white-space: nowrap;
	padding:10px;
	overflow: hidden;
	text-overflow: ellipsis;
        transition: background .25s ease-in-out;
	background: linear-gradient(left, rgba(255,255,255,0) 0%,
					rgba(255,255,255,1) 56%,
					rgba(255,255,255,1) 100%);
  }

table td a, table th a
  {
    display: block;
  }

#textbox
  {
        width:95%;
        text-align:left;
        margin:20px;
  }

thead th:first-child
  {
    border-radius: 6px 0 0 6px;
    background-color: lightblue; 
    width:50%;
  }
thead th:last-child
  {
    border-radius: 0 6px 6px 0;
    background-color: lightblue;
    width:50%;
  }
thead th:only-child
  {
    border-radius: 6px 6px 6px 6px;
    background-color: lightblue;
  }
thead th.hover:hover
  {
    color:#000;
    background:#FCF;
  }

tbody tr:nth-child(even)
  {
    background: #d5d5d5;
    box-shadow: 0 1px 0 rgba(255,255,255,100) inset;        
  }
tbody tr:hover
  {
    color:#000;
    background:#FCF;
  }
